<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation>Неможливо запустити зовнішню програму.
</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Помилка реєстрації файлу документації &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Не вдалось зареєструвати файл документації
%1

Причина:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Документацію успішно зареєстровано.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Не вдалось скасувати реєстрацію файлу документації
%1

Причина:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Реєстрацію документації успішно скасовано.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Помилка читання файлу колекції &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Помилка створення файлу колекції &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Неможливо завантажити драйвер бази даних SQLite!</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Додати закладку</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Закладка:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Додати в теку:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Нова тека</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Перейменувати теку</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Нова тека</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Ви збираєтесь видалити теку, що призведе до видалення її вмісту.&lt;br&gt;Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Керування закладками...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Додати закладку...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Видалити теку</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Перейменувати теку</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Показати закладку</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Показати закладку в новій вкладці</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Видалити закладку</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Перейменувати закладку</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Керування закладками</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Пошук:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Імпорт та резервування</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Імпортувати...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Експортувати...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Файли (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Зберегти файл</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Не можу зберегти закладки.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Ви збираєтесь видалити теку, що призведе до видалення її вмісту.&lt;br&gt;Ви впевнені, що хочете продовжити?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Видалити теку</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Перейменувати теку</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Показати закладку</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Показати закладку в новій вкладці</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Видалити закладку</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Перейменувати закладку</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адреса</translation>
    </message>
    <message>
        <source>Bookmarks Toolbar</source>
        <translation>Панель закладок</translation>
    </message>
    <message>
        <source>Toolbar Menu</source>
        <translation type="vanished">Панель закладок</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Меню закладок</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фільтр:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Print Document</source>
        <translation>Друкувати документ</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Re-builds the full text search index (potentially slow).
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Використання: assistant [Опції]

-collectionFile файл       Використати вказаний файл колекції
                           замість типового
-showUrl URL               Показати документ з URL.
-enableRemoteControl       Увімкнути віддалене керування Assistant.
-show віджет               Показати вказаний віджет (може бути:
                           &quot;contents&quot;, &quot;index&quot;, &quot;bookmarks&quot; чи &quot;search&quot;).
-activate віджет           Активувати вказаний віджет (може бути:
                           &quot;contents&quot;, &quot;index&quot;, &quot;bookmarks&quot; чи &quot;search&quot;).
-hide віджет               Сховати вказаний віджет (може бути:
                           &quot;contents&quot;, &quot;index&quot;, &quot;bookmarks&quot; чи &quot;search&quot;).
-register файлДовідки      Зареєструвати вказаний файл довідки
                           (.qch) в даному файлі колекції.
-unregister файлДовідки    Скасувати реєстрацію вказаного файлу довідки
                           (.qch) в даному файлі колекції.
-setCurrentFilter фільтр   Встановити фільтр в якості активного.
-remove-search-index       Видалити повнотекстовий пошуковий індекс.
-rebuild-search-index      Перебудувати повнотекстовий пошуковий індекс (можливо довго).
-quiet                     Не показувати жодних помилок чи статусних повідомлень.
-help                      Показати цю довідку.
</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation>Невідома опція: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Файл колекції &apos;%1&apos; не існує.</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Відсутній файл колекції.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Неправильний URL &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>URL відсутній.</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Невідомий віджет: %1</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Відсутній віджет.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Файл довідки Qt &apos;%1&apos; не існує.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Відсутній файл довідки.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Відсутній аргумент фільтра.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Примітка</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Відкрити посилання</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Відкрити посилання в новій вкладці</translation>
    </message>
</context>
<context>
    <name>ConversionWizard</name>
    <message>
        <source>Help Conversion Wizard</source>
        <translation type="obsolete">Майстер конвертування довідки</translation>
    </message>
    <message>
        <source>Converting %1...</source>
        <translation type="obsolete">Конвертую %1...</translation>
    </message>
    <message>
        <source>Writing help collection file...</source>
        <translation type="obsolete">Записую файл колекції довідки...</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation type="obsolete">Виконано.</translation>
    </message>
</context>
<context>
    <name>FilesPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>Files:</source>
        <translation type="obsolete">Файли:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Видалити</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="obsolete">Видалити все</translation>
    </message>
    <message>
        <source>Unreferenced Files</source>
        <translation type="obsolete">Файли,на які немає посилань</translation>
    </message>
    <message>
        <source>Remove files which are neither referenced by a keyword nor by the TOC.</source>
        <translation type="obsolete">Видаліть файли, на які немає посилань ні за ключовим словом, ні зі змісту.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Warning:&lt;/b&gt; When removing images or stylesheets, be aware that those files are not directly referenced by the .adp or .dcf file.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Попередження:&lt;/b&gt; При видаленні зображень чи таблиць стилів, майте на увазі, що на ці файли не має прямих посилань з файлу .adp чи .dcf.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>Додати назву фільтра</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Назва фільтра:</translation>
    </message>
</context>
<context>
    <name>FilterPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>Filter attributes for current documentation (comma separated list):</source>
        <translation type="obsolete">Атрибути фільтра для поточної документації (список, розділений комою):</translation>
    </message>
    <message>
        <source>Custom Filters</source>
        <translation type="obsolete">Користувацькі фільтри</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="obsolete">1</translation>
    </message>
    <message>
        <source>2</source>
        <translation type="obsolete">2</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="obsolete">Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Видалити</translation>
    </message>
    <message>
        <source>Filter Settings</source>
        <translation type="obsolete">Налаштування фільтрів</translation>
    </message>
    <message>
        <source>Specify the filter attributes for the documentation. If filter attributes are used, also define a custom filter for it. Both the filter attributes and the custom filters are optional.</source>
        <translation type="obsolete">Вкажіть атрибути фільтра для документації. Якщо використовуються атрибути фільтра, то, також, визначіть користувацький фільтр для нього. Як атрибути фільтра, так і користувацькі фільтри, є необов&apos;язковими.</translation>
    </message>
    <message>
        <source>Filter Name</source>
        <translation type="obsolete">Назва фільтра</translation>
    </message>
    <message>
        <source>Filter Attributes</source>
        <translation type="obsolete">Атрибути фільтра</translation>
    </message>
    <message>
        <source>The custom filter &apos;%1&apos; is defined multiple times.</source>
        <translation type="obsolete">Користувацький фільтр &apos;%1&apos; визначено декілька раз.</translation>
    </message>
    <message>
        <source>The attributes for custom filter &apos;%1&apos; are defined multiple times.</source>
        <translation type="obsolete">Атрибути для користувацького фільтра &apos;%1&apos; визначено декілька раз.</translation>
    </message>
    <message>
        <source>unfiltered</source>
        <comment>list of available documentation</comment>
        <translation type="obsolete">без фільтра</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Враховувати регістр</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Пошук з початку</translation>
    </message>
</context>
<context>
    <name>FinishPage</name>
    <message>
        <source>Converting File</source>
        <translation type="obsolete">Конвертування файлу</translation>
    </message>
    <message>
        <source>Creating the new Qt help files from the old ADP file.</source>
        <translation type="obsolete">Створення нових файлів довідки Qt зі старого файлу ADP.</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>Система &amp;писемності</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Шрифт</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>&amp;Стиль</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Розмір</translation>
    </message>
</context>
<context>
    <name>GeneralPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>Namespace:</source>
        <translation type="obsolete">Простір імен:</translation>
    </message>
    <message>
        <source>Virtual Folder:</source>
        <translation type="obsolete">Віртуальна тека:</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="obsolete">Загальні налаштування</translation>
    </message>
    <message>
        <source>Specify the namespace and the virtual folder for the documentation.</source>
        <translation type="obsolete">Вкажіть простір імен та віртуальну теку для документації.</translation>
    </message>
    <message>
        <source>Namespace Error</source>
        <translation type="obsolete">Помилка простору імен</translation>
    </message>
    <message>
        <source>The namespace contains some invalid characters.</source>
        <translation type="obsolete">Простір імен містить деякі неприпустимі символи.</translation>
    </message>
    <message>
        <source>Virtual Folder Error</source>
        <translation type="obsolete">Помилка віртуальної теки</translation>
    </message>
    <message>
        <source>The virtual folder contains some invalid characters.</source>
        <translation type="obsolete">Віртуальна тека містить деякі неприпустимі символи.</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперед</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Домівка</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>З&amp;більшити</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>З&amp;меншити</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>&amp;Копіювати виділений текст</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Друк...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>Пошук в &amp;тексті...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>По&amp;шук</translation>
    </message>
</context>
<context>
    <name>HelpEngineWrapper</name>
    <message>
        <source>Unfiltered</source>
        <translation>Без фільтра</translation>
    </message>
</context>
<context>
    <name>HelpGenerator</name>
    <message>
        <source>Warning: %1</source>
        <translation type="obsolete">Попередження: %1</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;about:blank&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Помилка 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Не вдалось знайти сторінку.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Відкрити посилання</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Копіювати &amp;адресу посилання</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Відкрити посилання в новій вкладці 	Ctrl+LMB</translation>
    </message>
    <message>
        <source>Error 404...</source>
        <translation>Помилка 404...</translation>
    </message>
    <message>
        <source>The page could not be found!</source>
        <translation>Не вдалось знайти сторінку!</translation>
    </message>
    <message>
        <source>Please make sure that you have all documentation sets installed.</source>
        <translation>Будь ласка, переконайтесь, що всі набори документації встановлено.</translation>
    </message>
    <message>
        <source>Error loading: %1</source>
        <translation>Помилка завантаження: %1</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>Відкрити посилання в новій сторінці</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&lt;center&gt;&lt;b&gt;Wizard Assistant&lt;/b&gt;&lt;/center&gt;</source>
        <translation type="obsolete">&lt;center&gt;&lt;b&gt;Майстер Assistant&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
</context>
<context>
    <name>IdentifierPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>Create identifiers</source>
        <translation type="obsolete">Створювати ідентифікатори</translation>
    </message>
    <message>
        <source>Global prefix:</source>
        <translation type="obsolete">Глобальний префікс:</translation>
    </message>
    <message>
        <source>Inherit prefix from file names</source>
        <translation type="obsolete">Успадковувати префікс з імен файлів</translation>
    </message>
    <message>
        <source>Identifiers</source>
        <translation type="obsolete">Ідентифікатори</translation>
    </message>
    <message>
        <source>This page allows you to create identifiers from the keywords found in the .adp or .dcf file.</source>
        <translation type="obsolete">Ця сторінка дозволяє вам створювати ідентифікатори з ключових слів, знайдених в файлі .adp чи .dcf.</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>&amp;Шукати:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Відкрити посилання</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Відкрити посилання в новій вкладці</translation>
    </message>
</context>
<context>
    <name>InputPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="obsolete">Ім&apos;я файлу:</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <source>Input File</source>
        <translation type="obsolete">Вхідний файл</translation>
    </message>
    <message>
        <source>Specify the .adp or .dcf file you want to convert to the new Qt help project format and/or collection format.</source>
        <translation type="obsolete">Вкажіть файл .adp чи .dcf, який ви бажаєте сконвертувати до нового формату проекту довідки Qt та/або формату колекції.</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation type="obsolete">Відкрити файл</translation>
    </message>
    <message>
        <source>Qt Help Files (*.adp *.dcf)</source>
        <translation type="obsolete">Файли довідки Qt (*.adp *.dcf)</translation>
    </message>
    <message>
        <source>File Open Error</source>
        <translation type="obsolete">Помилка відкриття файлу</translation>
    </message>
    <message>
        <source>The specified file could not be opened!</source>
        <translation type="obsolete">Не вдалось відкрити вказаний файл!</translation>
    </message>
    <message>
        <source>File Parsing Error</source>
        <translation type="obsolete">Помилка розбору файлу</translation>
    </message>
    <message>
        <source>Parsing error in line %1!</source>
        <translation type="obsolete">Помилка розбору в рядку %1!</translation>
    </message>
</context>
<context>
    <name>InstallDialog</name>
    <message>
        <source>Install Documentation</source>
        <translation type="vanished">Встановити документацію</translation>
    </message>
    <message>
        <source>Available Documentation:</source>
        <translation type="vanished">Доступна документація:</translation>
    </message>
    <message>
        <source>Install</source>
        <translation type="vanished">Встановити</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Скасувати</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Закрити</translation>
    </message>
    <message>
        <source>Installation Path:</source>
        <translation type="vanished">Шлях встановлення:</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <source>Downloading documentation info...</source>
        <translation type="vanished">Звантажую інформацію про документацію...</translation>
    </message>
    <message>
        <source>Download canceled.</source>
        <translation type="vanished">Звантаження скасоване.</translation>
    </message>
    <message>
        <source>Done.</source>
        <translation type="vanished">Виконано.</translation>
    </message>
    <message>
        <source>The file %1 already exists. Do you want to overwrite it?</source>
        <translation type="vanished">Файл %1 вже існує. Бажаєте перезаписати?</translation>
    </message>
    <message>
        <source>Unable to save the file %1: %2.</source>
        <translation type="vanished">Неможливо зберегти файл %1: %2.</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="vanished">Звантажую %1...</translation>
    </message>
    <message>
        <source>Download failed: %1.</source>
        <translation type="vanished">Звантаження провалилось: %1.</translation>
    </message>
    <message>
        <source>Documentation info file is corrupt!</source>
        <translation type="vanished">Файл інформації про документацію пошкоджений!</translation>
    </message>
    <message>
        <source>Download failed: Downloaded file is corrupted.</source>
        <translation type="vanished">Звантаження провалилось: Звантажений файл пошкоджений.</translation>
    </message>
    <message>
        <source>Installing documentation %1...</source>
        <translation type="vanished">Встановлюю документацію %1...</translation>
    </message>
    <message>
        <source>Error while installing documentation:
%1</source>
        <translation type="vanished">Помилка під час встановлення документації:
%1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Покажчик</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Зміст</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>Відкрити сторінки</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>Панель закладок</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>Пошук документації Qt...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Нова вкладка</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>Параметри &amp;сторінки...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Попередній перегляд...</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрити вкладку</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Ви&amp;йти</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Знайти &amp;наступне</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Знайти &amp;попереднє</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Налаштування...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>&amp;Нормальний розмір</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Ви&amp;йти</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>П&amp;ерейти</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Синхронізувати зі змістом</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронізувати</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Наступна сторінка</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Попередня сторінка</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Закладки</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>Про...</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Панель навігації</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>В&amp;ікно</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Масштабувати</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Мінімізувати</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Панелі</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Панель фільтрування</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Фільтрувати по:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Панель адреси</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Адреса:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Не вдалось знайти елемент, пов&apos;язаний зі змістом.</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %3 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %3 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
        <translation type="vanished">&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
        <translation type="obsolete">&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2012 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Про %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Оновлюється покажчик пошуку</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Не вдалось зареєструвати файл &apos;%1&apos;: %2</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>Закрити %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>Закрити все, крім %1</translation>
    </message>
</context>
<context>
    <name>OutputPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>Project file name:</source>
        <translation type="obsolete">Ім&apos;я файлу проекту:</translation>
    </message>
    <message>
        <source>Collection file name:</source>
        <translation type="obsolete">Ім&apos;я файлу колекції:</translation>
    </message>
    <message>
        <source>Output File Names</source>
        <translation type="obsolete">Імена вихідний файлів</translation>
    </message>
    <message>
        <source>Specify the file names for the output files.</source>
        <translation type="obsolete">Вкажіть імена вихідних файлів.</translation>
    </message>
    <message>
        <source>Convert...</source>
        <translation type="obsolete">Конвертувати...</translation>
    </message>
    <message>
        <source>Qt Help Project File</source>
        <translation type="obsolete">Файл проекту довідки Qt</translation>
    </message>
    <message>
        <source>Qt Help Collection Project File</source>
        <translation type="obsolete">Файл проекту колекції довідки Qt</translation>
    </message>
    <message>
        <source>The specified file %1 already exist.

Do you want to remove it?</source>
        <translation type="obsolete">Вказаний файл %1 вже існує

Бажаєте видалити його?</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Видалити</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Скасувати</translation>
    </message>
</context>
<context>
    <name>PathPage</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>File filters:</source>
        <translation type="obsolete">Фільтри файлів:</translation>
    </message>
    <message>
        <source>Documentation source file paths:</source>
        <translation type="obsolete">Шляхи вхідних файлів документації:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="obsolete">Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Видалити</translation>
    </message>
    <message>
        <source>Source File Paths</source>
        <translation type="obsolete">Шляхи вхідних файлів</translation>
    </message>
    <message>
        <source>Specify the paths where the sources files are located. By default, all files in those directories matched by the file filter will be included.</source>
        <translation type="obsolete">Вкажіть шляхи, де розташовані вхідні файли. Зазвичай, усі файли в цих теках, що відповідають фільтру файлів, будуть включені.</translation>
    </message>
    <message>
        <source>Source File Path</source>
        <translation type="obsolete">Шлях вхідного файлу</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>Додати документацію</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Стиснені файли довідки Qt (*.qch)</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>Простір імен %1 вже зареєстровано!</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>Вказаний файл не є коректним файлом довідки Qt!</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>Видалити документацію</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>Деякі документи, що зараз відкриті в Assistant, пов&apos;язані з документацією, яку ви намагаєтесь видалити. Видалення документації призведе до закриття цих документів.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Використовувати налаштування користувача</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Шрифти</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Параметри шрифту:</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Навігатор</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Програма</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Фільтри</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фільтр:</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>Атрибути:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Документація</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>Зареєстрована документація:</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Додати...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опції</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>При запуску довідки:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Показувати мою домашню сторінку</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Показувати порожню сторінку</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Показувати вкладку з минулого сеансу</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Домашня сторінка</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Поточна сторінка</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Порожня сторінка</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Відновити типово</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Зовнішній вигляд</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>Показувати вкладки для кожної окремої сторінки</translation>
    </message>
</context>
<context>
    <name>QCLuceneResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation type="obsolete">Результати пошуку</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation type="obsolete">Примітка:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed!</source>
        <translation type="obsolete">Результати пошуку можуть бути не повні, оскільки документація досі індексується!</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation type="obsolete">Ваш пошук не повернув результатів.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation type="obsolete">(Причиною цього може бути те, що документація досі індексується.)</translation>
    </message>
</context>
<context>
    <name>QCollectionGenerator</name>
    <message>
        <source>Unknown token at line %1.</source>
        <translation type="obsolete">Невідомий токен в рядку %1.</translation>
    </message>
    <message>
        <source>Missing end tags.</source>
        <translation type="obsolete">Відсутні кінцеві теги.</translation>
    </message>
    <message>
        <source>Qt Collection Generator version 1.0 (Qt %1)
</source>
        <translation type="obsolete">Qt Collection Generator версії 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>
Usage:

qcollectiongenerator &lt;collection-config-file&gt; [options]

  -o &lt;collection-file&gt;   Generates a collection file
                         called &lt;collection-file&gt;. If
                         this option is not specified
                         a default name will be used.
  -v                     Displays the version of
                         qcollectiongenerator.

</source>
        <translation type="obsolete">
Використання:

qcollectiongenerator &lt;файл-налаштувань-колекції&gt; [опції]

  -o &lt;файл-колекції&gt;   Згенерувати файл колекції з іменем
                                   &lt;файл-колекції&gt;. Якщо цю опцію не
                                   вказано, то використовуватиметься
                                   типове ім&apos;я
  -v                               Показати версію qcollectiongenerator.

</translation>
    </message>
    <message>
        <source>Unknown token at line %1. Expected &quot;QtHelpCollectionProject&quot;.</source>
        <translation type="obsolete">Невідомий токен в рядку %1. Очікувався &quot;QtHelpCollectionProject&quot;.</translation>
    </message>
    <message>
        <source>Missing input or output file for help file generation.</source>
        <translation type="obsolete">Відсутній вхідний чи вихідний файл для генерації файлу довідки.</translation>
    </message>
    <message>
        <source>Missing output file name.</source>
        <translation type="obsolete">Відсутнє ім&apos;я вихідного файлу.</translation>
    </message>
    <message>
        <source>Missing collection config file.</source>
        <translation type="obsolete">Відсутній файл налаштувань колекції.</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation type="obsolete">Не вдалось відкрити %1.
</translation>
    </message>
    <message>
        <source>Reading collection config file...
</source>
        <translation type="obsolete">Читання файлу налаштувань колекції...
</translation>
    </message>
    <message>
        <source>Collection config file error: %1
</source>
        <translation type="obsolete">Помилка файлу налаштувань колекції: %1
</translation>
    </message>
    <message>
        <source>Generating help for %1...
</source>
        <translation type="obsolete">Генерування довідки для %1...
</translation>
    </message>
    <message>
        <source>Creating collection file...
</source>
        <translation type="obsolete">Створення файлу колекції...
</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten.
</source>
        <translation type="obsolete">Неможливо перезаписати файл %1.
</translation>
    </message>
    <message>
        <source>Cannot open %1.
</source>
        <translation type="obsolete">Неможливо відкрити %1.
</translation>
    </message>
    <message>
        <source>Cannot open referenced image file %1.
</source>
        <translation type="obsolete">Неможливо відкрити файл зображення %1, на який є посилання.
</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation type="obsolete">Без назви</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &apos;%1&apos; is not set up yet!</source>
        <translation type="obsolete">Файл колекції &apos;%1&apos; ще не встановлено!</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation type="obsolete">Неможливо завантажити драйвер бази даних sqlite!</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation type="obsolete">Неможливо відкрити файл колекції: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1!</source>
        <translation type="obsolete">Неможливо створити таблиці в файлі %1!</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; already exists!</source>
        <translation type="obsolete">Файл колекції &apos;%1&apos; вже існує!</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation type="obsolete">Неможливо створити теку: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation type="obsolete">Неможливо скопіювати файл колекції: %1</translation>
    </message>
    <message>
        <source>Unknown filter &apos;%1&apos;!</source>
        <translation type="obsolete">Невідомий фільтр &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation type="obsolete">Неможливо зареєструвати фільтр %1!</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1!</source>
        <translation type="obsolete">Неможливо відкрити файл документації %1!</translation>
    </message>
    <message>
        <source>Invalid documentation file &apos;%1&apos;!</source>
        <translation type="obsolete">Неправильний файл документації &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered!</source>
        <translation type="obsolete">Простір імен %1 не зареєстровано!</translation>
    </message>
    <message>
        <source>Namespace %1 already exists!</source>
        <translation type="obsolete">Простір імен %1 вже існує!</translation>
    </message>
    <message>
        <source>Cannot register namespace &apos;%1&apos;!</source>
        <translation type="obsolete">Неможливо зареєструвати простір імен &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Cannot open database &apos;%1&apos; to optimize!</source>
        <translation type="obsolete">Неможливо відкрити базу даних &apos;%1&apos; для оптимізації!</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &apos;%1&apos; &apos;%2&apos;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation type="obsolete">Не можу відкрити базу даних &apos;%1&apos; &apos;%2&apos;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpEngineCore</name>
    <message>
        <source>Cannot open documentation file %1: %2!</source>
        <translation type="obsolete">Неможливо відкрити файл документації %1: %2!</translation>
    </message>
    <message>
        <source>The specified namespace does not exist!</source>
        <translation type="obsolete">Вказаний простір імен не існує!</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Missing output file name.</source>
        <translation type="obsolete">Відсутнє ім&apos;я вихідного файлу.</translation>
    </message>
    <message>
        <source>Qt Help Generator version 1.0 (Qt %1)
</source>
        <translation type="obsolete">Qt Help Generator версії 1.0 (Qt %1)
</translation>
    </message>
    <message>
        <source>Missing Qt help project file.</source>
        <translation type="obsolete">Відсутній файл проекту колекції довідки Qt.</translation>
    </message>
    <message>
        <source>Could not open %1.
</source>
        <translation type="obsolete">Не вдалось відкрити %1.
</translation>
    </message>
    <message>
        <source>
Usage:

qhelpgenerator &lt;help-project-file&gt; [options]

  -o &lt;compressed-file&gt;   Generates a Qt compressed help
                         file called &lt;compressed-file&gt;.
                         If this option is not specified
                         a default name will be used.
  -c                     Checks whether all links in HTML files
                         point to files in this help project.
  -v                     Displays the version of 
                         qhelpgenerator.

</source>
        <translation type="obsolete">
Використання:

qhelpgenerator &lt;файл-проекту-довідки&gt; [опції]

  -o &lt;стиснений-файл&gt;   Згенерувати стиснений файл довідки
                                      з іменем &lt;стиснений-файл&gt;. Якщо цю
                                      опцію не вказано, то буде використане
                                      типове ім&apos;я.
  -c                                 Перевірити, що усі посилання в файлах
                                      HTML files вказують на файли в цьому
                                      проекті довідки.
  -v                                 Показати версію qhelpgenerator.

</translation>
    </message>
    <message>
        <source>Could not create output directory: %1
</source>
        <translation type="obsolete">Не вдалось створити вихідну теку: %1
</translation>
    </message>
    <message>
        <source>Invalid help data!</source>
        <translation type="obsolete">Неправильні дані довідки!</translation>
    </message>
    <message>
        <source>No output file name specified!</source>
        <translation type="obsolete">Не вказане ім&apos;я вихідного файлу!</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten!</source>
        <translation type="obsolete">Неможливо перезаписати файл %1!</translation>
    </message>
    <message>
        <source>Building up file structure...</source>
        <translation type="obsolete">Побудова структури файлу....</translation>
    </message>
    <message>
        <source>Cannot open data base file %1!</source>
        <translation type="obsolete">Неможливо відкрити файл бази даних %1!</translation>
    </message>
    <message>
        <source>Cannot register namespace %1!</source>
        <translation type="obsolete">Неможливо зареєструвати простір імен %1!</translation>
    </message>
    <message>
        <source>Insert custom filters...</source>
        <translation type="obsolete">Вставка фільтрів користувача...</translation>
    </message>
    <message>
        <source>Insert help data for filter section (%1 of %2)...</source>
        <translation type="obsolete">Вставка даних довідки для розділу фільтра (%1 з %2)...</translation>
    </message>
    <message>
        <source>Documentation successfully generated.</source>
        <translation type="obsolete">Документацію успішно згенеровано.</translation>
    </message>
    <message>
        <source>Some tables already exist!</source>
        <translation type="obsolete">Деякі таблиці вже існують!</translation>
    </message>
    <message>
        <source>Cannot create tables!</source>
        <translation type="obsolete">Неможливо створити таблиці!</translation>
    </message>
    <message>
        <source>Cannot register virtual folder!</source>
        <translation type="obsolete">Неможливо зареєструвати віртуальну теку!</translation>
    </message>
    <message>
        <source>Insert files...</source>
        <translation type="obsolete">Вставка файлів...</translation>
    </message>
    <message>
        <source>The file %1 does not exist! Skipping it.</source>
        <translation type="obsolete">Файл %1 не існує! Пропускаємо його.</translation>
    </message>
    <message>
        <source>Cannot open file %1! Skipping it.</source>
        <translation type="obsolete">Неможливо відкрити файл %1! Пропускаємо його.</translation>
    </message>
    <message>
        <source>The filter %1 is already registered!</source>
        <translation type="obsolete">Фільтр %1 вже зареєстровано!</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation type="obsolete">Неможливо зареєструвати фільтр %1!</translation>
    </message>
    <message>
        <source>Insert indices...</source>
        <translation type="obsolete">Вставка індексів...</translation>
    </message>
    <message>
        <source>Insert contents...</source>
        <translation type="obsolete">Вставка змісту...</translation>
    </message>
    <message>
        <source>Cannot insert contents!</source>
        <translation type="obsolete">Неможливо вставити зміст!</translation>
    </message>
    <message>
        <source>Cannot register contents!</source>
        <translation type="obsolete">Неможливо зареєструвати зміст!</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; does not exist.</source>
        <translation type="obsolete">Файл &apos;%1&apos; не існує.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; cannot be opened.</source>
        <translation type="obsolete">Неможливо відкрити файл &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; contains an invalid link to file &apos;%2&apos;</source>
        <translation type="obsolete">Файл &apos;%1&apos; містить неправильне посилання до файлу &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Invalid links in HTML files.</source>
        <translation type="obsolete">Неправильні посилання в файлах HTML.</translation>
    </message>
</context>
<context>
    <name>QHelpProject</name>
    <message>
        <source>Unknown token.</source>
        <translation type="obsolete">Невідомий токен.</translation>
    </message>
    <message>
        <source>Unknown token. Expected &quot;QtHelpProject&quot;!</source>
        <translation type="obsolete">Невідомий токен. Очікувався &quot;QtHelpProject&quot;!</translation>
    </message>
    <message>
        <source>Error in line %1: %2</source>
        <translation type="obsolete">Помилка в рядку %1: %2</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax.</source>
        <translation type="obsolete">Віртуальна тека має неправильний синтаксис.</translation>
    </message>
    <message>
        <source>Namespace has invalid syntax.</source>
        <translation type="obsolete">Простір імен має неправильний синтаксис.</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject.</source>
        <translation type="obsolete">Відсутній простір імен в QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject</source>
        <translation type="obsolete">Відсутня віртуальна тека в QtHelpProject</translation>
    </message>
    <message>
        <source>The input file %1 could not be opened!</source>
        <translation type="obsolete">Не вдалось відкрити вхідний файл %1!</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation type="obsolete">Шукати:</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation type="obsolete">Попередній пошук</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation type="obsolete">Наступний пошук</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="obsolete">Шукати</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation type="obsolete">Розширений пошук</translation>
    </message>
    <message>
        <source>words &lt;B&gt;similar&lt;/B&gt; to:</source>
        <translation type="obsolete">слова &lt;B&gt;схожі&lt;/B&gt; на:</translation>
    </message>
    <message>
        <source>&lt;B&gt;without&lt;/B&gt; the words:</source>
        <translation type="obsolete">&lt;B&gt;без&lt;/B&gt; слів:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;exact phrase&lt;/B&gt;:</source>
        <translation type="obsolete">з &lt;B&gt;точною фразою&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;all&lt;/B&gt; of the words:</source>
        <translation type="obsolete">з &lt;B&gt;усіма&lt;/B&gt; словами:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;at least one&lt;/B&gt; of the words:</source>
        <translation type="obsolete">з &lt;B&gt;щонайменше одним&lt;/B&gt; зі слів:</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation type="obsolete">
            <numerusform>%1 - %2 з %n збіг</numerusform>
            <numerusform>%1 - %2 з %n збіги</numerusform>
            <numerusform>%1 - %2 з %n збігів</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation type="obsolete">0 - 0 з 0 збігів</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Зневадження віддаленого управління</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Отримано команду: %1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копіювати</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Копіювати &amp;адресу посилання</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Відкрити посилання в новій вкладці</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Виділити все</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Без назви)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Нова вкладка</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрити вкладку</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Закрити інші вкладки</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Додати закладку для цієї сторінки...</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Choose Topic</source>
        <translation>Оберіть тему</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Теми</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Показати</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фільтр</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Оберіть тему для &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
</context>
</TS>
